pub struct ListDelta {
pub added: Vec<String>,
pub removed: Vec<String>,
}Expand description
Membership delta for one list-valued global.
Fields
added: Vec<String>Item names present in b but not a, sorted.
removed: Vec<String>Item names present in a but not b, sorted.